@@ -5,7 +5,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     19/08/2007
-## RCS-ID:      $Id: make_v_cback.pl 2264 2007-11-05 23:23:35Z mbarbon $
+## RCS-ID:      $Id: make_v_cback.pl 2190 2007-08-21 21:19:42Z mbarbon $
 ## Copyright:   (c) 2007 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -22,9 +22,6 @@ my @macros =
      DEF_V_CBACK_BOOL__INT
      DEF_V_CBACK_BOOL__INT_pure
 
-     DEC_V_CBACK_BOOL__WXVARIANT_UINT_UINT
-     DEF_V_CBACK_BOOL__WXVARIANT_UINT_UINT_pure
-
      DEC_V_CBACK_BOOL__SIZET
      DEF_V_CBACK_BOOL__SIZET
      DEF_V_CBACK_BOOL__SIZET_pure
@@ -70,20 +67,10 @@ my @macros =
      DEF_V_CBACK_LONG__INT_INT_const
      DEF_V_CBACK_LONG__INT_INT_const_pure
 
-     DEC_V_CBACK_UINT__VOID
-     DEC_V_CBACK_UINT__VOID_const
-     DEF_V_CBACK_UINT__VOID
-     DEF_V_CBACK_UINT__VOID_const
-     DEF_V_CBACK_UINT__VOID_pure
-     DEF_V_CBACK_UINT__VOID_const_pure
-
      DEC_V_CBACK_VOID__INT_INT_LONG
      DEF_V_CBACK_VOID__INT_INT_LONG
      DEF_V_CBACK_VOID__INT_INT_LONG_pure
 
-     DEC_V_CBACK_VOID__mWXVARIANT_UINT_UINT_const
-     DEF_V_CBACK_VOID__mWXVARIANT_UINT_UINT_const_pure
-
      DEC_V_CBACK_VOID__SIZET_SIZET_const
      DEF_V_CBACK_VOID__SIZET_SIZET_const
 
@@ -97,37 +84,21 @@ my @macros =
      DEF_V_CBACK_WXCOORD__SIZET_const
      DEF_V_CBACK_WXCOORD__SIZET_pure
      DEF_V_CBACK_WXCOORD__SIZET_const_pure
-
-     DEC_V_CBACK_WXSTRING__WXSTRING
-     DEF_V_CBACK_WXSTRING__WXSTRING
-
-     DEC_V_CBACK_WXSTRING__UINT
-     DEC_V_CBACK_WXSTRING__UINT_const
-     DEF_V_CBACK_WXSTRING__UINT
-     DEF_V_CBACK_WXSTRING__UINT_const_pure
      );
 my %type_map =
   ( BOOL    => [ 'bool',    'SvTRUE( ret )', 'return false',
-                 'bool p%d', 'b', 'p%d', 'p%d' ],
+                 'bool p%d', 'b', 'p%d', ],
     SIZET   => [ 'size_t',  'SvIV( ret )', 'return 0',
-                 'size_t p%d', 'L', 'p%d', 'p%d' ],
+                 'size_t p%d', 'L', 'p%d', ],
     LONG    => [ 'long',    'SvIV( ret )', 'return 0',
-                 'long p%d', 'l', 'p%d', 'p%d' ],
+                 'long p%d', 'l', 'p%d', ],
     INT     => [ 'int',     'SvIV( ret )', 'return 0',
-                 'int p%d', 'i', 'p%d', 'p%d' ],
-    UINT    => [ 'unsigned int', 'SvUV( ret )', 'return 0',
-                 'unsigned int p%d', 'I', 'p%d', 'p%d' ],
+                 'int p%d', 'i', 'p%d', ],
     WXCOORD => [ 'wxCoord', 'SvIV( ret )', 'return 0',
-                 'wxCoord p%d', 'l', 'p%d', 'p%d' ],
+                 'wxCoord p%d', 'l', 'p%d', ],
     DOUBLE  => [ 'double',  'SvNV( ret )', 'return 0.0', ],
     VOID    => [ 'void',    ';',         , 'return',
                  ],
-    WXSTRING=> [ 'wxString','wxPli_sv_2_wxString( aTHX_ ret )', 'return wxEmptyString',
-                 'const wxString& p%d', 'P', '&p%d', 'p%d' ],
-    WXVARIANT=> [ 'wxVariant','wxPli_sv_2_wxvariant( aTHX_ ret )', 'return wxVariant()',
-                 'const wxVariant& p%d', 'q', '&p%d, "Wx::Variant"', 'p%d' ],
-    mWXVARIANT=> [ 'wxVariant','wxPli_sv_2_wxvariant( aTHX_ ret )', 'return wxVariant()',
-                 'wxVariant& p%d', 'q', '&p%d, "Wx::Variant"', 'p%d' ],
     );
 my %const_map =
   ( 0       => 'wxPli_NOCONST',
@@ -147,7 +118,7 @@ EOT
 
 foreach my $todo ( @todo ) {
     my $args = join '_', @{$todo->[2]};
-    my( $c_args, $p_args, $b_args, $tymap ) = macro_call_args( $todo );
+    my( $c_args, $p_args, $tymap ) = macro_call_args( $todo );
 
     if( $todo->[0] eq 'DEC' && $todo->[1] eq 'VOID' ) {
         my $name = sprintf 'DEC_V_CBACK_VOID__%s_', $args;
@@ -219,7 +190,7 @@ EOT
 
 foreach my $todo ( @todo ) {
     my $args = join '_', @{$todo->[2]};
-    my( $c_args, $p_args, $b_args, $tymap ) = macro_call_args( $todo );
+    my( $c_args, $p_args, $tymap ) = macro_call_args( $todo );
 
     my $const = $todo->[3]->{const} ? '_const' : '';
     my $pure = $todo->[3]->{pure} ? '_pure' : '';
@@ -246,7 +217,7 @@ EOT
             $todo->[1], $args, $const, $args, $type_map{$todo->[1]}[0],
             $const_map{$todo->[3]->{const}};
     } elsif( $todo->[0] eq 'DEF' && $todo->[1] eq 'VOID' ) {
-        my $callbase = sprintf 'BASE::METHOD(%s)', $b_args;
+        my $callbase = sprintf 'BASE::METHOD(%s)', $p_args;
         die 'No default value for pure function ', $todo->[1]
             if $todo->[3]{pure} && !$type_map{$todo->[1]}[2];
 
@@ -260,7 +231,7 @@ EOT
             ( $todo->[3]{pure} ? $type_map{$todo->[1]}[2] : $callbase ),
             $const_map{$todo->[3]->{const}};
     } elsif( $todo->[0] eq 'DEF' ) {
-        my $callbase = sprintf 'return BASE::METHOD(%s)', $b_args;
+        my $callbase = sprintf 'return BASE::METHOD(%s)', $p_args;
         die 'No default value for pure function ', $todo->[1]
             if $todo->[3]{pure} && !$type_map{$todo->[1]}[2];
 
@@ -306,13 +277,13 @@ sub parse_macro {
 sub macro_call_args {
     my( $todo ) = @_;
 
-    my( $c_args, $p_args, $b_args, $tymap );
+    my( $c_args, $p_args, $tymap );
     if( $todo->[2][0] eq 'VOID' ) {
-        $c_args = $p_args = $b_args = '';
+        $c_args = $p_args = '';
         $tymap = 'NULL';
     } else {
         my $c = 0;
-        my( @cargs, @pargs, @bargs );
+        my( @cargs, @pargs );
         foreach my $idx ( 0 .. $#{$todo->[2]} ) {
             my $type = $todo->[2][$idx];
             die 'Incomplete type definition for ', $type
@@ -322,13 +293,11 @@ sub macro_call_args {
             $cargs[$idx] = sprintf $type_map{$type}[3], $idx + 1;
             $tymap .= $type_map{$type}[4];
             $pargs[$idx] = sprintf $type_map{$type}[5], $idx + 1;
-            $bargs[$idx] = sprintf $type_map{$type}[6], $idx + 1;
         }
         $c_args = ' ' . join( ', ', @cargs ) . ' ';
         $p_args = join( ', ', @pargs );
-        $b_args = join( ', ', @bargs );
         $tymap  = qq{"$tymap"};
     }
 
-    return ( $c_args, $p_args, $b_args, $tymap );
+    return ( $c_args, $p_args, $tymap );
 }
